# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: python_pachyderm/proto/v2/license/license.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from python_pachyderm.proto.v2.enterprise import enterprise_pb2 as python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='python_pachyderm/proto/v2/license/license.proto',
  package='license_v2',
  syntax='proto3',
  serialized_options=b'Z-github.com/pachyderm/pachyderm/v2/src/license',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/python_pachyderm/proto/v2/license/license.proto\x12\nlicense_v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x35python_pachyderm/proto/v2/enterprise/enterprise.proto\"W\n\x0f\x41\x63tivateRequest\x12\x17\n\x0f\x61\x63tivation_code\x18\x01 \x01(\t\x12+\n\x07\x65xpires\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\":\n\x10\x41\x63tivateResponse\x12&\n\x04info\x18\x01 \x01(\x0b\x32\x18.enterprise_v2.TokenInfo\"\x1a\n\x18GetActivationCodeRequest\"\x81\x01\n\x19GetActivationCodeResponse\x12#\n\x05state\x18\x01 \x01(\x0e\x32\x14.enterprise_v2.State\x12&\n\x04info\x18\x02 \x01(\x0b\x32\x18.enterprise_v2.TokenInfo\x12\x17\n\x0f\x61\x63tivation_code\x18\x03 \x01(\t\"\x13\n\x11\x44\x65\x61\x63tivateRequest\"\x14\n\x12\x44\x65\x61\x63tivateResponse\"\x90\x01\n\x11\x41\x64\x64\x43lusterRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\t\x12\x14\n\x0cuser_address\x18\x04 \x01(\t\x12\x1d\n\x15\x63luster_deployment_id\x18\x05 \x01(\t\x12\x19\n\x11\x65nterprise_server\x18\x06 \x01(\x08\"$\n\x12\x41\x64\x64\x43lusterResponse\x12\x0e\n\x06secret\x18\x01 \x01(\t\"\"\n\x14\x44\x65leteClusterRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteClusterResponse\"\xca\x01\n\rClusterStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x14\n\x0c\x61uth_enabled\x18\x04 \x01(\x08\x12\x11\n\tclient_id\x18\x07 \x01(\t\x12\x32\n\x0elast_heartbeat\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"h\n\x14UpdateClusterRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x14\n\x0cuser_address\x18\x03 \x01(\t\x12\x1d\n\x15\x63luster_deployment_id\x18\x04 \x01(\t\"\x17\n\x15UpdateClusterResponse\"\x15\n\x13ListClustersRequest\"C\n\x14ListClustersResponse\x12+\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x19.license_v2.ClusterStatus\"\x12\n\x10\x44\x65leteAllRequest\"\x13\n\x11\x44\x65leteAllResponse\"h\n\x10HeartbeatRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x14\n\x0c\x61uth_enabled\x18\x04 \x01(\x08\x12\x11\n\tclient_id\x18\x05 \x01(\t\"B\n\x11HeartbeatResponse\x12-\n\x07license\x18\x01 \x01(\x0b\x32\x1c.enterprise_v2.LicenseRecord\"h\n\x0fUserClusterInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1d\n\x15\x63luster_deployment_id\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x19\n\x11\x65nterprise_server\x18\x04 \x01(\x08\"\x19\n\x17ListUserClustersRequest\"I\n\x18ListUserClustersResponse\x12-\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x1b.license_v2.UserClusterInfo2\xff\x05\n\x03\x41PI\x12G\n\x08\x41\x63tivate\x12\x1b.license_v2.ActivateRequest\x1a\x1c.license_v2.ActivateResponse\"\x00\x12\x62\n\x11GetActivationCode\x12$.license_v2.GetActivationCodeRequest\x1a%.license_v2.GetActivationCodeResponse\"\x00\x12J\n\tDeleteAll\x12\x1c.license_v2.DeleteAllRequest\x1a\x1d.license_v2.DeleteAllResponse\"\x00\x12M\n\nAddCluster\x12\x1d.license_v2.AddClusterRequest\x1a\x1e.license_v2.AddClusterResponse\"\x00\x12V\n\rDeleteCluster\x12 .license_v2.DeleteClusterRequest\x1a!.license_v2.DeleteClusterResponse\"\x00\x12S\n\x0cListClusters\x12\x1f.license_v2.ListClustersRequest\x1a .license_v2.ListClustersResponse\"\x00\x12V\n\rUpdateCluster\x12 .license_v2.UpdateClusterRequest\x1a!.license_v2.UpdateClusterResponse\"\x00\x12J\n\tHeartbeat\x12\x1c.license_v2.HeartbeatRequest\x1a\x1d.license_v2.HeartbeatResponse\"\x00\x12_\n\x10ListUserClusters\x12#.license_v2.ListUserClustersRequest\x1a$.license_v2.ListUserClustersResponse\"\x00\x42/Z-github.com/pachyderm/pachyderm/v2/src/licenseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2.DESCRIPTOR,])




_ACTIVATEREQUEST = _descriptor.Descriptor(
  name='ActivateRequest',
  full_name='license_v2.ActivateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation_code', full_name='license_v2.ActivateRequest.activation_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires', full_name='license_v2.ActivateRequest.expires', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=238,
)


_ACTIVATERESPONSE = _descriptor.Descriptor(
  name='ActivateResponse',
  full_name='license_v2.ActivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='license_v2.ActivateResponse.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=298,
)


_GETACTIVATIONCODEREQUEST = _descriptor.Descriptor(
  name='GetActivationCodeRequest',
  full_name='license_v2.GetActivationCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=326,
)


_GETACTIVATIONCODERESPONSE = _descriptor.Descriptor(
  name='GetActivationCodeResponse',
  full_name='license_v2.GetActivationCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='license_v2.GetActivationCodeResponse.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='license_v2.GetActivationCodeResponse.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_code', full_name='license_v2.GetActivationCodeResponse.activation_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=458,
)


_DEACTIVATEREQUEST = _descriptor.Descriptor(
  name='DeactivateRequest',
  full_name='license_v2.DeactivateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=479,
)


_DEACTIVATERESPONSE = _descriptor.Descriptor(
  name='DeactivateResponse',
  full_name='license_v2.DeactivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=501,
)


_ADDCLUSTERREQUEST = _descriptor.Descriptor(
  name='AddClusterRequest',
  full_name='license_v2.AddClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='license_v2.AddClusterRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='license_v2.AddClusterRequest.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='license_v2.AddClusterRequest.secret', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_address', full_name='license_v2.AddClusterRequest.user_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_deployment_id', full_name='license_v2.AddClusterRequest.cluster_deployment_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enterprise_server', full_name='license_v2.AddClusterRequest.enterprise_server', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=648,
)


_ADDCLUSTERRESPONSE = _descriptor.Descriptor(
  name='AddClusterResponse',
  full_name='license_v2.AddClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret', full_name='license_v2.AddClusterResponse.secret', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=686,
)


_DELETECLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteClusterRequest',
  full_name='license_v2.DeleteClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='license_v2.DeleteClusterRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=722,
)


_DELETECLUSTERRESPONSE = _descriptor.Descriptor(
  name='DeleteClusterResponse',
  full_name='license_v2.DeleteClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=747,
)


_CLUSTERSTATUS = _descriptor.Descriptor(
  name='ClusterStatus',
  full_name='license_v2.ClusterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='license_v2.ClusterStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='license_v2.ClusterStatus.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='license_v2.ClusterStatus.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_enabled', full_name='license_v2.ClusterStatus.auth_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='license_v2.ClusterStatus.client_id', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_heartbeat', full_name='license_v2.ClusterStatus.last_heartbeat', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='license_v2.ClusterStatus.created_at', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=952,
)


_UPDATECLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateClusterRequest',
  full_name='license_v2.UpdateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='license_v2.UpdateClusterRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='license_v2.UpdateClusterRequest.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_address', full_name='license_v2.UpdateClusterRequest.user_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_deployment_id', full_name='license_v2.UpdateClusterRequest.cluster_deployment_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=1058,
)


_UPDATECLUSTERRESPONSE = _descriptor.Descriptor(
  name='UpdateClusterResponse',
  full_name='license_v2.UpdateClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1060,
  serialized_end=1083,
)


_LISTCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListClustersRequest',
  full_name='license_v2.ListClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1106,
)


_LISTCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListClustersResponse',
  full_name='license_v2.ListClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='license_v2.ListClustersResponse.clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1108,
  serialized_end=1175,
)


_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='license_v2.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1177,
  serialized_end=1195,
)


_DELETEALLRESPONSE = _descriptor.Descriptor(
  name='DeleteAllResponse',
  full_name='license_v2.DeleteAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1197,
  serialized_end=1216,
)


_HEARTBEATREQUEST = _descriptor.Descriptor(
  name='HeartbeatRequest',
  full_name='license_v2.HeartbeatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='license_v2.HeartbeatRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='license_v2.HeartbeatRequest.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='license_v2.HeartbeatRequest.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_enabled', full_name='license_v2.HeartbeatRequest.auth_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='license_v2.HeartbeatRequest.client_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1322,
)


_HEARTBEATRESPONSE = _descriptor.Descriptor(
  name='HeartbeatResponse',
  full_name='license_v2.HeartbeatResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='license', full_name='license_v2.HeartbeatResponse.license', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1324,
  serialized_end=1390,
)


_USERCLUSTERINFO = _descriptor.Descriptor(
  name='UserClusterInfo',
  full_name='license_v2.UserClusterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='license_v2.UserClusterInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_deployment_id', full_name='license_v2.UserClusterInfo.cluster_deployment_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='license_v2.UserClusterInfo.address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enterprise_server', full_name='license_v2.UserClusterInfo.enterprise_server', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1496,
)


_LISTUSERCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListUserClustersRequest',
  full_name='license_v2.ListUserClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1498,
  serialized_end=1523,
)


_LISTUSERCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListUserClustersResponse',
  full_name='license_v2.ListUserClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='license_v2.ListUserClustersResponse.clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1525,
  serialized_end=1598,
)

_ACTIVATEREQUEST.fields_by_name['expires'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVATERESPONSE.fields_by_name['info'].message_type = python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2._TOKENINFO
_GETACTIVATIONCODERESPONSE.fields_by_name['state'].enum_type = python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2._STATE
_GETACTIVATIONCODERESPONSE.fields_by_name['info'].message_type = python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2._TOKENINFO
_CLUSTERSTATUS.fields_by_name['last_heartbeat'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTERSTATUS.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCLUSTERSRESPONSE.fields_by_name['clusters'].message_type = _CLUSTERSTATUS
_HEARTBEATRESPONSE.fields_by_name['license'].message_type = python__pachyderm_dot_proto_dot_v2_dot_enterprise_dot_enterprise__pb2._LICENSERECORD
_LISTUSERCLUSTERSRESPONSE.fields_by_name['clusters'].message_type = _USERCLUSTERINFO
DESCRIPTOR.message_types_by_name['ActivateRequest'] = _ACTIVATEREQUEST
DESCRIPTOR.message_types_by_name['ActivateResponse'] = _ACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['GetActivationCodeRequest'] = _GETACTIVATIONCODEREQUEST
DESCRIPTOR.message_types_by_name['GetActivationCodeResponse'] = _GETACTIVATIONCODERESPONSE
DESCRIPTOR.message_types_by_name['DeactivateRequest'] = _DEACTIVATEREQUEST
DESCRIPTOR.message_types_by_name['DeactivateResponse'] = _DEACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['AddClusterRequest'] = _ADDCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['AddClusterResponse'] = _ADDCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['DeleteClusterRequest'] = _DELETECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterResponse'] = _DELETECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['ClusterStatus'] = _CLUSTERSTATUS
DESCRIPTOR.message_types_by_name['UpdateClusterRequest'] = _UPDATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterResponse'] = _UPDATECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['ListClustersRequest'] = _LISTCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListClustersResponse'] = _LISTCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllResponse'] = _DELETEALLRESPONSE
DESCRIPTOR.message_types_by_name['HeartbeatRequest'] = _HEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['HeartbeatResponse'] = _HEARTBEATRESPONSE
DESCRIPTOR.message_types_by_name['UserClusterInfo'] = _USERCLUSTERINFO
DESCRIPTOR.message_types_by_name['ListUserClustersRequest'] = _LISTUSERCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListUserClustersResponse'] = _LISTUSERCLUSTERSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivateRequest = _reflection.GeneratedProtocolMessageType('ActivateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.ActivateRequest)
  })
_sym_db.RegisterMessage(ActivateRequest)

ActivateResponse = _reflection.GeneratedProtocolMessageType('ActivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATERESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.ActivateResponse)
  })
_sym_db.RegisterMessage(ActivateResponse)

GetActivationCodeRequest = _reflection.GeneratedProtocolMessageType('GetActivationCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVATIONCODEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.GetActivationCodeRequest)
  })
_sym_db.RegisterMessage(GetActivationCodeRequest)

GetActivationCodeResponse = _reflection.GeneratedProtocolMessageType('GetActivationCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVATIONCODERESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.GetActivationCodeResponse)
  })
_sym_db.RegisterMessage(GetActivationCodeResponse)

DeactivateRequest = _reflection.GeneratedProtocolMessageType('DeactivateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.DeactivateRequest)
  })
_sym_db.RegisterMessage(DeactivateRequest)

DeactivateResponse = _reflection.GeneratedProtocolMessageType('DeactivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATERESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.DeactivateResponse)
  })
_sym_db.RegisterMessage(DeactivateResponse)

AddClusterRequest = _reflection.GeneratedProtocolMessageType('AddClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDCLUSTERREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.AddClusterRequest)
  })
_sym_db.RegisterMessage(AddClusterRequest)

AddClusterResponse = _reflection.GeneratedProtocolMessageType('AddClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDCLUSTERRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.AddClusterResponse)
  })
_sym_db.RegisterMessage(AddClusterResponse)

DeleteClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.DeleteClusterRequest)
  })
_sym_db.RegisterMessage(DeleteClusterRequest)

DeleteClusterResponse = _reflection.GeneratedProtocolMessageType('DeleteClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.DeleteClusterResponse)
  })
_sym_db.RegisterMessage(DeleteClusterResponse)

ClusterStatus = _reflection.GeneratedProtocolMessageType('ClusterStatus', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERSTATUS,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.ClusterStatus)
  })
_sym_db.RegisterMessage(ClusterStatus)

UpdateClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.UpdateClusterRequest)
  })
_sym_db.RegisterMessage(UpdateClusterRequest)

UpdateClusterResponse = _reflection.GeneratedProtocolMessageType('UpdateClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.UpdateClusterResponse)
  })
_sym_db.RegisterMessage(UpdateClusterResponse)

ListClustersRequest = _reflection.GeneratedProtocolMessageType('ListClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.ListClustersRequest)
  })
_sym_db.RegisterMessage(ListClustersRequest)

ListClustersResponse = _reflection.GeneratedProtocolMessageType('ListClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.ListClustersResponse)
  })
_sym_db.RegisterMessage(ListClustersResponse)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALLREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.DeleteAllRequest)
  })
_sym_db.RegisterMessage(DeleteAllRequest)

DeleteAllResponse = _reflection.GeneratedProtocolMessageType('DeleteAllResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALLRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.DeleteAllResponse)
  })
_sym_db.RegisterMessage(DeleteAllResponse)

HeartbeatRequest = _reflection.GeneratedProtocolMessageType('HeartbeatRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.HeartbeatRequest)
  })
_sym_db.RegisterMessage(HeartbeatRequest)

HeartbeatResponse = _reflection.GeneratedProtocolMessageType('HeartbeatResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.HeartbeatResponse)
  })
_sym_db.RegisterMessage(HeartbeatResponse)

UserClusterInfo = _reflection.GeneratedProtocolMessageType('UserClusterInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERCLUSTERINFO,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.UserClusterInfo)
  })
_sym_db.RegisterMessage(UserClusterInfo)

ListUserClustersRequest = _reflection.GeneratedProtocolMessageType('ListUserClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERCLUSTERSREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.ListUserClustersRequest)
  })
_sym_db.RegisterMessage(ListUserClustersRequest)

ListUserClustersResponse = _reflection.GeneratedProtocolMessageType('ListUserClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERCLUSTERSRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.license.license_pb2'
  # @@protoc_insertion_point(class_scope:license_v2.ListUserClustersResponse)
  })
_sym_db.RegisterMessage(ListUserClustersResponse)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='license_v2.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1601,
  serialized_end=2368,
  methods=[
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='license_v2.API.Activate',
    index=0,
    containing_service=None,
    input_type=_ACTIVATEREQUEST,
    output_type=_ACTIVATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActivationCode',
    full_name='license_v2.API.GetActivationCode',
    index=1,
    containing_service=None,
    input_type=_GETACTIVATIONCODEREQUEST,
    output_type=_GETACTIVATIONCODERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='license_v2.API.DeleteAll',
    index=2,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=_DELETEALLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddCluster',
    full_name='license_v2.API.AddCluster',
    index=3,
    containing_service=None,
    input_type=_ADDCLUSTERREQUEST,
    output_type=_ADDCLUSTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCluster',
    full_name='license_v2.API.DeleteCluster',
    index=4,
    containing_service=None,
    input_type=_DELETECLUSTERREQUEST,
    output_type=_DELETECLUSTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListClusters',
    full_name='license_v2.API.ListClusters',
    index=5,
    containing_service=None,
    input_type=_LISTCLUSTERSREQUEST,
    output_type=_LISTCLUSTERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCluster',
    full_name='license_v2.API.UpdateCluster',
    index=6,
    containing_service=None,
    input_type=_UPDATECLUSTERREQUEST,
    output_type=_UPDATECLUSTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Heartbeat',
    full_name='license_v2.API.Heartbeat',
    index=7,
    containing_service=None,
    input_type=_HEARTBEATREQUEST,
    output_type=_HEARTBEATRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserClusters',
    full_name='license_v2.API.ListUserClusters',
    index=8,
    containing_service=None,
    input_type=_LISTUSERCLUSTERSREQUEST,
    output_type=_LISTUSERCLUSTERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from python_pachyderm.proto.v2.pfs import pfs_pb2 as python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.v2.pps import pps_pb2 as python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2


class APIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InspectJob = channel.unary_unary(
                '/pps_v2.API/InspectJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
                )
        self.InspectJobSet = channel.unary_stream(
                '/pps_v2.API/InspectJobSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobSetRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
                )
        self.ListJob = channel.unary_stream(
                '/pps_v2.API/ListJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
                )
        self.ListJobSet = channel.unary_stream(
                '/pps_v2.API/ListJobSet',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobSetRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobSetInfo.FromString,
                )
        self.SubscribeJob = channel.unary_stream(
                '/pps_v2.API/SubscribeJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SubscribeJobRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
                )
        self.DeleteJob = channel.unary_unary(
                '/pps_v2.API/DeleteJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StopJob = channel.unary_unary(
                '/pps_v2.API/StopJob',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InspectDatum = channel.unary_unary(
                '/pps_v2.API/InspectDatum',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectDatumRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.FromString,
                )
        self.ListDatum = channel.unary_stream(
                '/pps_v2.API/ListDatum',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListDatumRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.FromString,
                )
        self.RestartDatum = channel.unary_unary(
                '/pps_v2.API/RestartDatum',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RestartDatumRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreatePipeline = channel.unary_unary(
                '/pps_v2.API/CreatePipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreatePipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InspectPipeline = channel.unary_unary(
                '/pps_v2.API/InspectPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectPipelineRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
                )
        self.ListPipeline = channel.unary_stream(
                '/pps_v2.API/ListPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListPipelineRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
                )
        self.DeletePipeline = channel.unary_unary(
                '/pps_v2.API/DeletePipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeletePipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StartPipeline = channel.unary_unary(
                '/pps_v2.API/StartPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StartPipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StopPipeline = channel.unary_unary(
                '/pps_v2.API/StopPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopPipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RunPipeline = channel.unary_unary(
                '/pps_v2.API/RunPipeline',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunPipelineRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RunCron = channel.unary_unary(
                '/pps_v2.API/RunCron',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunCronRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateSecret = channel.unary_unary(
                '/pps_v2.API/CreateSecret',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreateSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteSecret = channel.unary_unary(
                '/pps_v2.API/DeleteSecret',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListSecret = channel.unary_unary(
                '/pps_v2.API/ListSecret',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfos.FromString,
                )
        self.InspectSecret = channel.unary_unary(
                '/pps_v2.API/InspectSecret',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectSecretRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfo.FromString,
                )
        self.DeleteAll = channel.unary_unary(
                '/pps_v2.API/DeleteAll',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetLogs = channel.unary_stream(
                '/pps_v2.API/GetLogs',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.GetLogsRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.LogMessage.FromString,
                )
        self.ActivateAuth = channel.unary_unary(
                '/pps_v2.API/ActivateAuth',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthResponse.FromString,
                )
        self.UpdateJobState = channel.unary_unary(
                '/pps_v2.API/UpdateJobState',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.UpdateJobStateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RunLoadTestDefault = channel.unary_unary(
                '/pps_v2.API/RunLoadTestDefault',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.FromString,
                )


class APIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def InspectJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectJobSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJob(self, request, context):
        """ListJob returns information about current and past Pachyderm jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJobSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectDatum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDatum(self, request, context):
        """ListDatum returns information about each datum fed to a Pachyderm job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RestartDatum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunCron(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAll(self, request, context):
        """DeleteAll deletes everything
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateAuth(self, request, context):
        """An internal call that causes PPS to put itself into an auth-enabled state
        (all pipeline have tokens, correct permissions, etcd)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateJobState(self, request, context):
        """An internal call used to move a job from one state to another
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunLoadTestDefault(self, request, context):
        """RunLoadTest runs the default load test.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InspectJob': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
            ),
            'InspectJobSet': grpc.unary_stream_rpc_method_handler(
                    servicer.InspectJobSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobSetRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
            ),
            'ListJob': grpc.unary_stream_rpc_method_handler(
                    servicer.ListJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
            ),
            'ListJobSet': grpc.unary_stream_rpc_method_handler(
                    servicer.ListJobSet,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobSetRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobSetInfo.SerializeToString,
            ),
            'SubscribeJob': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SubscribeJobRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
            ),
            'DeleteJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StopJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StopJob,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InspectDatum': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectDatum,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectDatumRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.SerializeToString,
            ),
            'ListDatum': grpc.unary_stream_rpc_method_handler(
                    servicer.ListDatum,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListDatumRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.SerializeToString,
            ),
            'RestartDatum': grpc.unary_unary_rpc_method_handler(
                    servicer.RestartDatum,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RestartDatumRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreatePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreatePipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InspectPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectPipelineRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.SerializeToString,
            ),
            'ListPipeline': grpc.unary_stream_rpc_method_handler(
                    servicer.ListPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListPipelineRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.SerializeToString,
            ),
            'DeletePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeletePipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StartPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.StartPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StartPipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StopPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.StopPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopPipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RunPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.RunPipeline,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunPipelineRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RunCron': grpc.unary_unary_rpc_method_handler(
                    servicer.RunCron,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunCronRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSecret,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreateSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSecret,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSecret,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfos.SerializeToString,
            ),
            'InspectSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectSecret,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectSecretRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfo.SerializeToString,
            ),
            'DeleteAll': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAll,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.GetLogs,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.GetLogsRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.LogMessage.SerializeToString,
            ),
            'ActivateAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateAuth,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthResponse.SerializeToString,
            ),
            'UpdateJobState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateJobState,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.UpdateJobStateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RunLoadTestDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.RunLoadTestDefault,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pps_v2.API', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class API(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def InspectJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/InspectJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectJobSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/InspectJobSet',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectJobSetRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/ListJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJobSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/ListJobSet',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListJobSetRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobSetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/SubscribeJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SubscribeJobRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/DeleteJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/StopJob',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectDatum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/InspectDatum',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectDatumRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDatum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/ListDatum',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListDatumRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DatumInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RestartDatum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/RestartDatum',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RestartDatumRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/CreatePipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreatePipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/InspectPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectPipelineRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/ListPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ListPipelineRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/DeletePipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeletePipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/StartPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StartPipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/StopPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.StopPipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/RunPipeline',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunPipelineRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunCron(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/RunCron',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.RunCronRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/CreateSecret',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.CreateSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/DeleteSecret',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.DeleteSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/ListSecret',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfos.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/InspectSecret',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.InspectSecretRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.SecretInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/DeleteAll',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/pps_v2.API/GetLogs',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.GetLogsRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.LogMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/ActivateAuth',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.ActivateAuthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateJobState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/UpdateJobState',
            python__pachyderm_dot_proto_dot_v2_dot_pps_dot_pps__pb2.UpdateJobStateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunLoadTestDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pps_v2.API/RunLoadTestDefault',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_pfs_dot_pfs__pb2.RunLoadTestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
